/************************************************
 *  Program Name:  ibm-encoder.ch 
 *
 *  Description:
 *       This program calculates the encoder 
 *       count required for a given set of IBM 7575
 *       joint angles.
 *
 *  Usage:
 *     ./ibm-encoder theta_1 theta_2 theta_3 theta_4
 *
 *  Example
 *     ./ibm-encoder 120 143 -75 0
 *           
 *  Author: Stephen Nestinger   March 28 2007
 ***************************************************/

#include <stdio.h>
#include <numeric.h>
#include <robot.h>

int main(int argc, char **argv)
{
    
    array double disp[4]={0};
    array double enc[4]={0};

    array double counts_rev[4];   /* Encoder resolution */
    array double enc_offset[4];   /* joint offset */
    array double JM_matrix[4][4];

    JM_matrix  = robot2_JM_matrix;  /* Obtain gear ratios robot2 */
    counts_rev = robot2_counts_rev; /* Obtain Enc res robot2 */
    enc_offset = robot2_enc_offset; /* Obtain Enc offset */

    int i;
    for(i=0;i<4;i++) disp[i]=atof(argv[i+1]);
    printf("\ndisp: %.2f", disp);

    enc = (inverse(JM_matrix)*disp).*(counts_rev/360.0)+enc_offset;

    for(i=0;i<4;i++) 
        printf("%d:%.2f ", i, enc[i]);
    printf("\n");
    return 0;
}
