/**************************************************
*  Program Name:  ibm7575-pu-pickup.ch 
*
*  Description:
*       This program assists in the calibration
*       of the IBM 7575 for the WorkCell 
*       collaboration.
*
* Author: Stephen S. Nestinger, March 28 2007
***************************************************/
#include <stdio.h>
#include <ctype.h>
#include "robot.h"

#define NUM_RUNS 3

int main(void) 
{
   array double jold[4] = {0,0,0,0},
                jnew[4],
                trans_matrix[4][4],
                end_tmatrix[4][4],
                ready2[4] = {120.0,143.0,-0.21,0};
   double P[3][2]={319, 387, 271.5, 370, 224, 363},
          conveyerPos[3] = {427, 203, 200},
          conveyerDisp[1]={0};
   int status, j, choice, stop = 0,
       ibm_conf = FLIP;
   array double curpos[4]={0,0,0,0};
   char buf[100];

   // Instanciate CRobot class 
   class CRobot ibm = CRobot(ROBOT2, RUN_REALTIME),
           conveyer = CRobot(CONVEYER1, RUN_REALTIME);

   // Calibrate IBM robot and conveyer 
   status = ibm.Calibrate();    
   status = conveyer.Calibrate();    
   
   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = ibm.Drive(ready2); 
   status = ibm.MoveWait(); 
   status = ibm.MoveReady(); 
   status = ibm.MoveWait(); 
  
   // Move the conveyer into position
   conveyerDisp[0] = conveyerPos[0];
   status = conveyer.Drive(conveyerDisp);
   conveyer.MoveWait();
   conveyerDisp[0] = conveyerPos[1];
   status = conveyer.Drive(conveyerDisp);
   conveyer.MoveWait();
   conveyerDisp[0] = conveyerPos[2];
   status = conveyer.Drive(conveyerDisp);
   conveyer.MoveWait();


   while(!stop)
   { 
     printf("Go to pickup location or 'quit'(q) to exit\n"
             "blue (b), orange (o), yellow (y), move (m): ");
     fgets(buf, 95, stdin);
     choice = tolower(buf[0]); 
     switch(choice)
     {
       case 'b':
       {
         // Calculate required movement for desired position
         trans_matrix=robot2ZeroPosition;
         trans_matrix[0][0] =  cos(110*3.1415/180);
         trans_matrix[0][1] = -sin(110*3.1415/180);
         trans_matrix[1][0] =  sin(110*3.1415/180);
         trans_matrix[1][1] =  cos(110*3.1415/180);
         trans_matrix[0][3] =   P[0][0]; 
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] =  -20.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();


         // calculate required movement for desired position
         trans_matrix[0][3] =   P[0][0];
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] = -150.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();

         // Open IBM robot gripper
         printf("IBM Opening Gripper\n");
         status = ibm.GripperOpen();
         break;
       }
       case 'o':
       {
         // Calculate required movement for desired position
         trans_matrix=robot2ZeroPosition;
         trans_matrix[0][0] =  cos(110*3.1415/180);
         trans_matrix[0][1] = -sin(110*3.1415/180);
         trans_matrix[1][0] =  sin(110*3.1415/180);
         trans_matrix[1][1] =  cos(110*3.1415/180);
         trans_matrix[0][3] =   P[1][0]; 
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] =  -20.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();


         // calculate required movement for desired position
         trans_matrix[0][3] =   P[1][0];
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] = -150.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();

         // Open IBM robot gripper
         printf("IBM Opening Gripper\n");
         status = ibm.GripperOpen();
         break;
       }
       case 'y':
       {
          // Calculate required movement for desired position
         trans_matrix=robot2ZeroPosition;
         trans_matrix[0][0] =  cos(110*3.1415/180);
         trans_matrix[0][1] = -sin(110*3.1415/180);
         trans_matrix[1][0] =  sin(110*3.1415/180);
         trans_matrix[1][1] =  cos(110*3.1415/180);
         trans_matrix[0][3] =   P[2][0]; 
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] =  -20.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();


         // calculate required movement for desired position
         trans_matrix[0][3] =   P[2][0];
         trans_matrix[1][3] =  340.0;
         trans_matrix[2][3] = -150.0;
         printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
            trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
         ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
         ibm.Drive(jnew);
         ibm.MoveWait();

         // Open IBM robot gripper
         printf("IBM Opening Gripper\n");
         status = ibm.GripperOpen();
         break;
       }
       case 'm':
       {
         curpos[0] = trans_matrix[0][3];
         curpos[1] = trans_matrix[1][3];
         curpos[2] = trans_matrix[2][3];
         curpos[3] = 110;

         while(1)
         {
           printf("Enter new position and rotation or 'mainmenu' (m)\n"
                  "Current: %.2f %.2f %.2f %.2f\n"
                  "x y z theta: ", curpos[0],curpos[1],curpos[2],curpos[3]);
           fgets(buf, 95, stdin);
           if(tolower(buf[0]) == 'm') break;
           sscanf(buf, "%lf %lf %lf %lf", 
               &curpos[0], &curpos[1], &curpos[2], &curpos[3]);

           printf("IBM Moving:\n   X:  %.2fmm Y:  %.2fmm Z: %.2fmm"
                   " theta %.2fdeg\n", curpos[0], curpos[1], curpos[2], 
                                     curpos[3]);

           // Calculate required movement for desired position
           trans_matrix = robot2ZeroPosition;
           trans_matrix[0][0] =  cos(curpos[3]*3.1415/180);
           trans_matrix[0][1] = -sin(curpos[3]*3.1415/180);
           trans_matrix[1][0] =  sin(curpos[3]*3.1415/180);
           trans_matrix[1][1] =  cos(curpos[3]*3.1415/180);
           trans_matrix[0][3] = curpos[0];
           trans_matrix[1][3] = curpos[1];
           trans_matrix[2][3] = curpos[2];
           ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
           printf("IBM Drive To: %.2f", jnew);
           ibm.Drive(jnew);
           ibm.MoveWait();
         }
         break;
       }
       case 'q':
       {
         stop = 1;
         break;
       }
       default:
         printf("Invalid input\n\n");
     }
   }

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = ibm.Drive(ready2); 
   status = ibm.MoveWait(); 
   status = ibm.MoveReady(); 
   status = ibm.MoveWait(); 

   // Close IBM robot gripper
   status = ibm.GripperClose();

   // Disable IBM robot
   status = ibm.Disable();
  // status = conveyer.Disable();

   printf("Program Complete.\n\n");

   return 0;
}
