/**************************************************
*  Program Name:  workcell-pickup-setup.ch
*
*  Description:
*    This program setups the workcell for a 
*    workcell collaboration demo. You normally
*    run this program before running 
*    workcell-pickup.ch to speed up the demo setup.
*
* Author:  Stephen S. Nestinger, April 5, 2007
***************************************************/
#include "robot.h"

#define NUM_RUNS 3

int main(void) 
{
   // IBM Variables
   array double ibm_ready2[4] = {120.0,143.0,-0.21,0};
   int status;

   class CRobot  ibm = CRobot(ROBOT2,    RUN_REALTIME),
                puma = CRobot(ROBOT1,    RUN_REALTIME),
            conveyer = CRobot(CONVEYER1, RUN_REALTIME);

   // Calibrate Robots
   status = puma.Calibrate();    
   status = ibm.Calibrate();    
   status = conveyer.Calibrate();    

   array double disp[1] = {2500};
   status = conveyer.Drive(disp);
   
   // Move IBM robot to ready position 
   //   ibm_ready2 position is ready position with Z = -50
   status = ibm.Drive(ibm_ready2); 
   status = ibm.MoveWait(); 
   status = ibm.MoveReady(); 
   status = ibm.MoveWait(); 
  
   // PUMA: Close the gripper
   status = puma.GripperClose();
   // IBM: Close the gripper
   status = ibm.GripperClose();

   status = conveyer.MoveWait();

   // ALL: Disable
   status = puma.Disable();
   status = ibm.Disable();
   status = conveyer.Disable();

   printf("Program Complete.\n\n");
   return 0;
}
