/**************************************************
*  Program Name:  ibm7575-inputpos.ch 
*
*  Description:
*       This program demostrates the control of
*       of the IBM 7575 using coordinates with
*       inverse kinematics. 
*
* Author: Stephen S. Nestinger   March 28 2007
***************************************************/
#include <stdio.h>
#include <ctype.h>
#include "robot.h"

int main(void) 
{
   array double jold[4] = {0,0,0,0},
                jnew[4],
                trans_matrix[4][4],
                ready2[4] = {120.0,143.0,-0.21,0};
   array double curpos[4]={0,0,0,0};
   int status,
       j,	
       robot2_conf = FLIP;
   char buf[100];

   // Instanciate CRobot class 
   class CRobot robot2 = CRobot(ROBOT2, RUN_REALTIME);

   // Calibrate IBM robot 
   status = robot2.Calibrate();    
   
   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 

   curpos[0] =  286.8;
   curpos[1] =  237.7;
   curpos[2] =  -35.0;
   curpos[3] =   85.0;
 
   while(1)
   { 

     printf("IBM Moving:\n   X:  %.2fmm Y:  %.2fmm Z: %.2fmm theta %.2fdeg\n",
        curpos[0], curpos[1], curpos[2], curpos[3]);

     // Calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][0] =  cos(curpos[3]*3.1415/180);
     trans_matrix[0][1] = -sin(curpos[3]*3.1415/180);
     trans_matrix[1][0] =  sin(curpos[3]*3.1415/180);
     trans_matrix[1][1] =  cos(curpos[3]*3.1415/180);
     trans_matrix[0][3] = curpos[0];
     trans_matrix[1][3] = curpos[1];
     trans_matrix[2][3] = curpos[2];
     robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
     robot2.Drive(jnew);
     robot2.MoveWait();

     memset(buf, 0, sizeof(buf));
     printf("Enter new position and rotation or 'quit' to exit:\nx y z theta:\n");
     fgets(buf, 95, stdin);
     if(tolower(buf[0]) == 'q') break;
     sscanf(buf, "%lf %lf %lf %lf", 
             &curpos[0], &curpos[1], &curpos[2], &curpos[3]);
   }

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 

   // Close IBM robot gripper
   status = robot2.GripperClose();

   // Disable IBM robot
   status = robot2.Disable();

   printf("Program Complete.\n\n");

   return 0;
}
