/**************************************************
*  Program Name:  ibm7575.ch 
*
*  Description:
*       This program demostrates the use of 
*       linemove to move the tooltip of the IBM 
*       7575 along a line.
*
* Author: Stephen S. Nestinger   March 28 2007
***************************************************/
#include <stdio.h>
#include <ctype.h>
#include "robot.h"

int main(void) 
{
   array double jold[4] = {0,0,0,0},
                jnew[4],
                trans_matrix[4][4],
                end_tmatrix[4][4],
                ready2[4] = {120.0,143.0,-0.21,0};
   int status,
       j,	
       robot2_conf = FLIP;
   char buf[100];

   // Instanciate CRobot class 
   class CRobot robot2 = CRobot(ROBOT2, RUN_REALTIME);

   // Calibrate IBM robot 
   status = robot2.Calibrate();    
   
   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 

   printf("IBM Moving:\n   X:  355mm Y:  295mm Z: -150mm theta 100deg\n");

   // Calculate required movement for desired position
   trans_matrix=robot2ZeroPosition;
   trans_matrix[0][0] =  cos(100*3.1415/180);
   trans_matrix[0][1] = -sin(100*3.1415/180);
   trans_matrix[1][0] =  sin(100*3.1415/180);
   trans_matrix[1][1] =  cos(100*3.1415/180);
   trans_matrix[0][3] =  355.0;
   trans_matrix[1][3] =  295.0;
   trans_matrix[2][3] = -150.0;
   robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
   robot2.Drive(jnew);
   robot2.MoveWait();

   printf("IBM Line Move using 10 intermediate points:\n");  
   printf("  FROM - X:  355mm Y:  295mm Z: -150mm theta 100deg\n");
   printf("  TO   - X:  310mm Y:  295mm Z: -150mm theta 100deg\n");

   end_tmatrix = trans_matrix;
   end_tmatrix[0][3] =  310;
   end_tmatrix[1][3] =  295;
   end_tmatrix[2][3] = -150;

   robot2.MoveLine(trans_matrix, end_tmatrix, 10, robot2_conf);

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 

   // Close IBM robot gripper
   status = robot2.GripperClose();

   // Disable IBM robot
   status = robot2.Disable();

   printf("Program Complete.\n\n");

   return 0;
}
