/**************************************************
*  Program Name:  puma560-inputpos.ch 
*
*  Description:
*       This program demostrates the control
*  of the PUMA 560 using coordinates via inverse
*  kinematics.
*           
*  Author: Stephen Nestinger   March 28 2007 
***************************************************/
#include <stdio.h>
#include <ctype.h>
#include "robot.h"

int main(void) 
{
   array double jold[6] = {0,0,0,0,0,0},
                jnew[6],
                trans_matrix[4][4];
   int status,
       j,
       robot1_conf = FLIP|ABOVE|RIGHT;
   char buf[100];
   array double curpos[4]={0,0,0};
   array double curort[4]={0,0,0};
   double phi, theta, gamma;

   class CRobot puma560 = CRobot(ROBOT1, RUN_REALTIME);

   // Calibrate and home PUMA 560 robot 
   status = puma560.Calibrate();

   // Move PUMA robot to zero position
   puma560.MoveReady();
   puma560.MoveWait();

   trans_matrix = robot1ZeroPosition;
   curpos[0] = trans_matrix[0][3]; 
   curpos[1] = trans_matrix[1][3]; 
   curpos[2] = trans_matrix[2][3];

   while(1)
   {
     printf("Current Pos (%.2f, %.2f, %.2f)\n",
             curpos[0], curpos[1], curpos[2]);
     printf("Current Orientation (%.2f, %.2f, %.2f)\n",
             curort[1], curort[2], curort[0]);

     printf("Enter new pos and ort ('quit' to exit)\n"
            "x y z theta gamma phi (mm and deg)\n");
     fgets(buf, 99, stdin);

     if(tolower(buf[0])=='q') break;

     sscanf(buf, "%lf %lf %lf %lf %lf %lf", 
             &curpos[0], &curpos[1], &curpos[2],
             &curort[1], &curort[2], &curort[0]);

     phi   = curort[0];
     theta = curort[1];
     gamma = curort[2];

     trans_matrix[0][0]= C(phi)*C(gamma)-S(phi)*C(theta)*S(gamma);
     trans_matrix[0][1]= -C(phi)*S(gamma)-S(phi)*C(theta)*C(gamma);
     trans_matrix[0][2]= S(phi)*S(theta);
     trans_matrix[1][0]= S(phi)*C(gamma)+C(phi)*C(theta)*S(gamma);
     trans_matrix[1][1]= -S(phi)*S(gamma)+C(phi)*C(theta)*C(gamma);
     trans_matrix[1][2]= -C(phi)*S(theta);
     trans_matrix[2][0]= S(theta)*S(gamma);
     trans_matrix[2][1]= S(theta)*C(gamma);
     trans_matrix[2][2]= C(theta);

     trans_matrix[0][3]=curpos[0];
     trans_matrix[1][3]=curpos[1];
     trans_matrix[2][3]=curpos[2];
     puma560.InverseKinematics(trans_matrix,jold,jnew,robot1_conf);
     puma560.Drive(jnew);
     puma560.MoveWait();
   }

   puma560.MoveReady();
   puma560.MoveWait();
   puma560.GripperClose();

   // Disable
   puma560.Disable();

   printf("Program Complete.\n");
}

