/**************************************************
*  Program Name:  ibm7575-pickup.ch 
*
*  Description:
*       This program demostrates the coordinated 
*       motion of the IBM 7575 4 Axis Robotic Arm 
*       and a conveyor system.
*
* Author: Stephen S. Nestinger   March 28, 2007
***************************************************/
#include <stdio.h>
#include "robot.h"

#define NUM_RUNS 3

int main(void) 
{
   array double jold[4] = {0,0,0,0},
                jnew[4],
                trans_matrix[4][4],
                end_tmatrix[4][4],
                ready2[4] = {120.0,143.0,-0.21,0};
   double P[3][2]={319, 387, 271.5, 370, 224, 363},
          conveyorPos[3] = {427, 203, 200},
          conveyorDisp[1]={0};
   int status,
       j,	
       ibm_conf = FLIP;

   // Instanciate CRobot class 
   class CRobot ibm = CRobot(ROBOT2, RUN_SIMULATION),
           conveyor = CRobot(CONVEYOR1, RUN_SIMULATION);

   // Calibrate IBM robot and conveyor 
   status = ibm.Calibrate();    
   status = conveyor.Calibrate();    
   
   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = ibm.Drive(ready2); 
   status = ibm.MoveWait(); 
   status = ibm.MoveReady(); 
   status = ibm.MoveWait(); 
  
   for(j=0; j<NUM_RUNS; j++)
   { 
     // Move the conveyor into position
     conveyorDisp[0] = conveyorPos[j];
     conveyor.Drive(conveyorDisp);

     // Calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][0] =  cos(110*3.1415/180);
     trans_matrix[0][1] = -sin(110*3.1415/180);
     trans_matrix[1][0] =  sin(110*3.1415/180);
     trans_matrix[1][1] =  cos(110*3.1415/180);
     trans_matrix[0][3] =   P[j][0]; 
     trans_matrix[1][3] =  340.0;
     trans_matrix[2][3] =  -20.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();


     // calculate required movement for desired position
     trans_matrix[0][3] =   P[j][0];
     trans_matrix[1][3] =  340.0;
     trans_matrix[2][3] = -150.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();

     // Open IBM robot gripper
     printf("IBM Opening Gripper\n");
     status = ibm.GripperOpen();

     // calculate required movement for desired position
     trans_matrix[0][3] =   P[j][0];
     trans_matrix[1][3] =  340.0;
     trans_matrix[2][3] = -150.0;
     end_tmatrix = trans_matrix;
     end_tmatrix[1][3] = P[j][1];
     ibm.MoveLine(trans_matrix, end_tmatrix, 10, ibm_conf);

     // Close IBM robot gripper
     printf("IBM Closing Gripper\n");
     status = ibm.GripperClose();

     // Calculate required movement for desired position
     trans_matrix = end_tmatrix;
     trans_matrix[2][3] =  -20.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();

     // Calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][0] =  cos(20*3.1415/180);
     trans_matrix[0][1] = -sin(20*3.1415/180);
     trans_matrix[1][0] =  sin(20*3.1415/180);
     trans_matrix[1][1] =  cos(20*3.1415/180);
     trans_matrix[0][3] =  344.0;
     trans_matrix[1][3] = -408.0;
     trans_matrix[2][3] =  -20.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();

     // Calculate required movement for desired position
     trans_matrix[2][3] =  -92.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();

     // Open IBM robot gripper
     printf("IBM Opening Gripper\n");
     status = ibm.GripperOpen();

     // Calculate required movement for desired position
     trans_matrix[2][3] =  -20.0;
     printf("IBM Moving - X: %.2fmm Y: %.2fmm Z: %.2fmm\n",
        trans_matrix[0][3], trans_matrix[1][3], trans_matrix[2][3]);
     ibm.InverseKinematics(trans_matrix, jold, jnew, ibm_conf);
     ibm.Drive(jnew);
     ibm.MoveWait();

   }

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = ibm.Drive(ready2); 
   status = ibm.MoveWait(); 
   status = ibm.MoveReady(); 
   status = ibm.MoveWait(); 

   // Close IBM robot gripper
   status = ibm.GripperClose();

   // Disable IBM robot
   status = ibm.Disable();

   printf("Program Complete.\n\n");

   return 0;
}
