/**************************************************
*  Program Name:  ibm7575.ch 
*
*  Description:
*       This program demostrates the coordinate motion
*       of robot2 -- the IBM 7575 4 Axis Robotic Arm
*
* Author:             Xudong Hu   Jul 10 1999
* Updated: Stephen S. Nestinger   March 28 2007
***************************************************/
#include "robot.h"

int main(void) 
{
   array double jold[4] = {0,0,0,0},
                jnew[4],
                trans_matrix[4][4],
                ready2[4] = {120.0,143.0,-0.21,0};
                //ready2[4] = {120.0,143.0,-0.21,-359.8};
   int status,
       j,	
       robot2_conf = FLIP;

   // Instanciate CRobot class 
   class CRobot robot2 = CRobot(ROBOT2, RUN_SIMULATION);

   // Calibrate IBM robot 
   status = robot2.Calibrate();    
   
   // Move IBM robot to zero position
   //   zero position is home position
   //   ( already there after Calibrate is called )
   // status = robot2.MoveZero();    
   // status = robot2.MoveWait();

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 
  
   for(j=0; j<1; j++)
   { 
     printf("IBM Moving - X:  500mm Y:  200mm Z: -20mm\n");

     // Calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][3]+= 500.0;
     trans_matrix[1][3]+= 300.0;
     trans_matrix[2][3]+= -20.0;
     robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
     robot2.Drive(jnew);
     robot2.MoveWait();

     printf("IBM Opening Gripper\n");

     // Open IBM robot gripper
     status = robot2.GripperOpen();

     printf("IBM Moving - X:  500mm Y:  300mm Z: -150mm\n");
     // calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][3]+= 500.0;
     trans_matrix[1][3]+= 300.0;
     trans_matrix[2][3]+= -150.0;
     robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
     robot2.Drive(jnew);
     robot2.MoveWait();

     printf("IBM Closing Gripper\n");

     // Close IBM robot gripper
     status = robot2.GripperClose();
       
     printf("IBM Moving - X:  500mm Y:  300mm Z: -20mm\n");
     // calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][3]+= 500.0;
     trans_matrix[1][3]+= 300.0;
     trans_matrix[2][3]+= -20.0;
     robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
     robot2.Drive(jnew);
     robot2.MoveWait();

     printf("IBM Moving - X:  570mm Y: -340mm Z: -20mm\n");

     // Calculate required movement for desired position
     trans_matrix=robot2ZeroPosition;
     trans_matrix[0][3]+=  570.0;
     trans_matrix[1][3]+= -340.0;
     trans_matrix[2][3]+=  -20.0;
     robot2.InverseKinematics(trans_matrix, jold, jnew, robot2_conf);
     robot2.Drive(jnew);
     robot2.MoveWait();

     printf("IBM Opening Gripper\n");

     // Open IBM robot gripper
     status = robot2.GripperOpen();
   }

   // Move IBM robot to ready position 
   //   ready2 position is ready position with Z = -50
   status = robot2.Drive(ready2); 
   status = robot2.MoveWait(); 
   status = robot2.MoveReady(); 
   status = robot2.MoveWait(); 

   // Close IBM robot gripper
   status = robot2.GripperClose();

   // Disable IBM robot
   status = robot2.Disable();

   printf("Program Complete.\n\n");

   return 0;
}
