/************************************************
 *  Program Name:  puma560-pickup.ch 
 *
 *  Description:
 *       This program demostrates the coordinated 
 *       motion of the Puma 560 6 Axis Robotic 
 *       Arm and a conveyor system.
 *
 * Author: Stephen S. Nestinger   March 28 2007
 **************************************************/
#include <stdio.h>
#include "robot.h"

int main(void) 
{
   array double puma_jold[6] = {0,0,0,0,0,0},
                puma_jnew[6],
                puma_tm[4][4],
                puma_etm[4][4],
                endPos[3] = {-643, -702, -765},
                conveyorPos[3] = {427, 203, 200},
                conveyorDisp[1];
   int status,
       j,
       puma_conf = FLIP|ABOVE|RIGHT;
   char buf[100];
   array double curpos[4]={0,0,0};
   array double curort[4]={0,0,0};
   double phi, theta, gamma;

   class CRobot puma560  = CRobot(ROBOT1,    RUN_SIMULATION),
                conveyor = CRobot(CONVEYOR1, RUN_SIMULATION);

   // Calibrate and home PUMA 560 robot 
   status = puma560.Calibrate();
   status = conveyor.Calibrate();

   // Move PUMA robot to zero position
   puma560.MoveReady();
   puma560.MoveWait();

   array double puma_DropoffTM[4][4] = 
      {-0.996195, -0.087156, -0.000000,  270.00,
       -0.087156,  0.996195,  0.000000, -646.00,
       -0.000000, -0.000000, -1.000000, -200.00,
        0.000000,  0.000000,  0.000000,    1.00};

   array double puma_PickupTM[4][4] = 
      {0.358368,  0.933580,  0.000000, -653.00,
       0.933580, -0.358368,  0.000000,  315.00,
       0.000000,  0.000000, -1.000000, -250.00,
       0.000000,  0.000000,  0.000000,    1.00};
   

 for(j=0;j<3;j++)
 {
   conveyorDisp[0] = conveyorPos[j];
   conveyor.Drive(conveyorDisp);

   puma_tm = puma_PickupTM;
   puma560.InverseKinematics(puma_tm,puma_jold,puma_jnew,puma_conf);
   puma560.Drive(puma_jnew);
   puma560.MoveWait();
   conveyor.MoveWait();

   puma560.GripperOpen();

   puma_etm = puma_PickupTM;
   puma_etm[2][3] = -310.00;
   puma560.MoveLine(puma_tm, puma_etm, 8, puma_conf);
   puma560.MoveWait();

   puma560.GripperClose();

   puma_tm = puma_etm;
   puma_etm[2][3] = -280.00;
   puma560.MoveLine(puma_tm, puma_etm, 5, puma_conf);
   puma560.MoveWait();

   puma_tm[2][3] = 0;
   puma560.InverseKinematics(puma_tm,puma_jold,puma_jnew,puma_conf);
   puma560.Drive(puma_jnew);
   puma560.MoveWait();

   puma_tm = puma_DropoffTM;
   puma_tm[0][3] = -400;
   puma_tm[1][3] = -300;
   puma_tm[2][3] =    0;
   puma560.InverseKinematics(puma_tm,puma_jold,puma_jnew,puma_conf);
   puma560.Drive(puma_jnew);
   puma560.MoveWait();

   puma_tm = puma_DropoffTM;
   puma_tm[1][3] = endPos[j];
   puma560.InverseKinematics(puma_tm,puma_jold,puma_jnew,puma_conf);
   puma560.Drive(puma_jnew);
   puma560.MoveWait();

   puma_etm = puma_tm;
   puma_etm[2][3] = -255.00;
   puma560.MoveLine(puma_tm, puma_etm, 8, puma_conf);
   puma560.MoveWait();

   puma560.GripperOpen();

   puma_tm = puma_etm;
   puma_etm[2][3] = -200.00;
   puma560.MoveLine(puma_tm, puma_etm, 8, puma_conf);
   puma560.MoveWait();

   puma_tm = puma_DropoffTM;
   puma_tm[0][3] = -400;
   puma_tm[1][3] = -300;
   puma_tm[2][3] =    0;
   puma560.InverseKinematics(puma_tm,puma_jold,puma_jnew,puma_conf);
   puma560.Drive(puma_jnew);
   puma560.MoveWait();
   }

   puma560.MoveReady();
   puma560.MoveWait();
   puma560.GripperClose();

   // Disable
   puma560.Disable();
   conveyor.Disable();

   printf("Program Complete.\n");
}

