/**************************************************
*  Program Name:  workcell.ch 
*
*  Description:
*       This program demostrates the coordinate motion
*  of robot1--Puma 560,robot2--IBM 7575 and conveyor1
*  Flex-Link robotic manipulators.
*           
*  Author: Xudong Hu, July 10,1999
*  Updated: Stephen S. Nestinger, March 28 2007
***************************************************/
#include "robot.h"

int main() 
{
 array double P1[4][4], P2[4][4],           // T-matrix for Puma 
              I1[4][4], I2[4][4];           // T-matrix for IBM 
 double jold1[6]={0,0,0,0,0,0},             // Puma old joint values
             jold2[4] = {0,0,0,0},          // IBM old joint values
             p1[6], p2[6], i1[4], i2[4],    // Puma & IBM joint values
             c1[1];                         // conveyor1 joint value
 int robot1conf = FLIP|ABOVE|LEFT;          // Puma is configurated as flip, below and left
 int robot2conf = FLIP;                     // IBM is configurated as flip
 int i;
 char ch;

 /* setup and check PMAC DACs output */
 class CRobot robot2=CRobot(ROBOT2,RUN_SIMULATION),        // setup IBM 7575
              robot1=CRobot(ROBOT1,RUN_SIMULATION),        // setup Puma 560
              conveyor=CRobot(CONVEYOR1,RUN_SIMULATION);   // setup Conveyer

 robot1.Calibrate();                        // calibrate Puma 560
 robot2.Calibrate();                        // calibrate IBM 7575
 conveyor.Calibrate();                      // calibrate IBM 7575
 
 /* calculate the position of the arms and conveyor */ 
 P1 = P2 = robot1ZeroPosition;              // set P1 and P2 to zero position
 P1[0][3] += 300; P1[1][3] += 300;
 P1[2][3] += -150;                          // Puma wrist position
 robot1.InverseKinematics(P1,jold1,p1,robot1conf); // inverse kinematics
 P2[0][3] += 0; P2[1][3] += 300;
 P2[2][3] += -100;                          // Puma wrist position
 robot1.InverseKinematics(P2,jold1,p2,robot1conf); // inverse kinematics

 I1 = I2 = robot2ZeroPosition;              // set I1 and I2 to zero position
 I1[0][3] += 700; I1[1][3] += 200;
 I1[2][3] += -60;                           // IBM wrist position
 robot2.InverseKinematics(I1,jold2,i1,robot2conf); // inverse kinematics
 I2[0][3] += 500; I2[1][3] += -200;
 I2[2][3] += -20;                           // IBM wrist position
 robot2.InverseKinematics(I2,jold2,i2,robot2conf); // inverse kinematics

 c1[0] = 500;                              // move conveyor1 250 mm
 
 for(i=0; i<2; i++) 
 {                       // a loop for assembly operations
  robot1.GripperOpen();                     // open Puma 560 gripper
  robot1.Drive(p1);                         // move Puma to position P1
  robot2.Drive(i1);                         // move IBM  to position I1
  conveyor.Drive(c1);                       // move conveyor1 500mm

  
  robot1.MoveWait();               // wait for Puma 560 to complete its motion
  robot2.MoveWait();               // wait for IBM 7575 to complete its motion
  conveyor.MoveWait();             // wait for conveyor to complete its motion

  robot1.GripperClose();           // PUMA picks up a part at P1
  robot2.GripperOpen();            // IBM stacks a part at I1

  robot1.Drive(p2);                // move Puma to position P2
  robot2.Drive(i2);                // move IBM to position I2

  robot1.MoveWait();               // wait for Puma 560 to complete its motion
  robot2.MoveWait();               // wait for IBM 7575 to complete its motion
  conveyor.MoveWait();             // wait for conveyor to complete its motion
  robot1.GripperOpen();            // PUMA releases the part at P2
  robot2.GripperClose();           // IBM picks up the part at I2

 }

 /* shutdown the system */
 robot1.MoveReady();               // move Puma to ready position
 robot2.MoveReady();               // move IBM to ready position
 robot1.MoveWait();               // wait for Puma 560 to complete its motion
 robot2.MoveWait();               // wait for IBM 7575 to complete its motion
 printf("Turn off Two Robots arm power.\n");
 printf("Hit any key to continue.\n");
 ch = getchar();

 robot1.Disable();                 // disable Puma 560
 robot2.Disable();                 // disable IBM 7575
 conveyor.Disable();               // disable conveyor1

 exit(0);                          // exit the CH language environment 
}
