/******************************************************
*  Program Name:  Conveyor1.h
*
*  Functionality: Provide setup information for
*                 Conveyor,which connected with
*                 board of servo2,channel 5.
*                  
*  Author: Xudong Hu                Jan 25, 1998
*  Modified by Xudong Hu         on Mar 25, 1999
*  Modified by Stephen Nestinger on Aug 21, 2006
*******************************************************/

#ifndef Conveyor1_h
#define Conveyor1_h

#define CONVEYOR1 3
#define CONVEYOR1_PMAC 1 // PMAC device number conveyor is attached to
#define CONVEYOR1_NUM_JOINTS 1

char * conveyor1_init[][27] = 
{
    // Definition 
    "i0500 = 1",         // Motor Enable                               
    "i0501 = 0",         // Commutation Disable                        
    "i0502 = $78102",    // DAC Output Address                         
    "i0503 = $3505",     // Pos FB Data Address                        
    "i0504 = $3505",     // Vel FB Data Address                        
    "i0505 = $35C0",     // Master Position Address                    
    "i0506 = 0",         // Master Follow Enable                       
    "i0507 = 96",        // Master Scale Factor                        
    "i0508 = 96",        // Position Scale Factory                     
    "i0509 = 96",        // Velocity Scale Factor                      
    "i0510 = $0",        // Power-on Servo Position Address            

    // Safety 
    "i0511 = 1600",      // Enable Motor Fatal following Error limit (1/16 Cts) 
    "i0512 = 0",         // Disable  Motor Warn following Error limit  
    "i0513 = 0",         // Software Pos Limit +, Unit: Encoder Counts 
    "i0514 = 0",         // Software Pos Limit -, Unit: Encoder Counts 
    "i0515 = 0.25",      // Pos Limit Decel Rate, Unit: Counts/msec^2  
    "i0516 = 0.2",       // Max Velocity, Unit: Counts/msec^2          
    "i0517 = 0.02",      // Max Acceleration, Unit: Counts/msec^2      
    "i0519 = 0.20",      // Max Jog Acceleration, Unit: Counts/msec^2  

    // Movement 
    "i0520 = 1",         // Motor Jog/Home Accel Time, Unit: msec      
    "i0521 = 0",         // Motor Jog/Home S-Curve Time,   Unit: msec  
    "i0522 = 0.2",       // Motor Jog Speed, Unit: Counts/msec         
    "i0523 = 0.2",       // Motor Home Speed & Dir, Unit: Counts/msec  
    "i0524 = $120001",   // Motor Flag Mode Control                    
    "i0525 = $78100",    // Motor Flag Address                         
    "i0526 = 0",         // Motor Home Offset                          
    "i0527 = 0",         // Motor Position Rollover Range              
    "i0528 = 200",       // Motor In-Position Band                     
    "i0529 = 0",         // Motor Output/1st Phase Offset              

    // Basic Servo 
//    "i0530 = 500000",    // PID Proportional Gain, Unit: DAVbits/Count 
//    "i0531 = 7500",      // PID Derivative Gain, DACbits/(Counts/cycle)
//    "i0532 = 7500",      // PID Vel FF Gain, DACbits/(Counts/cycle)    
//    "i0533 = 500",       // PID Inte Gain, DACbits/(Counts*cycles)     
    "i0530 = 500000",    // PID Proportional Gain, Unit: DAVbits/Count 
    "i0531 = 7500",      // PID Derivative Gain, DACbits/(Counts/cycle)
    "i0532 = 0",      // PID Vel FF Gain, DACbits/(Counts/cycle)    
    "i0533 = 0",     // PID Inte Gain, DACbits/(Counts*cycles)     

    "i0534 = 1",         // PID Inte Mode                              
    "i0535 = 0",         // PID Accel FF Gain, DACbits/(Counts/cycle^2)
    "i0536 = 0",         // PID Notch Filter Coefficient N1            
    "i0537 = 0",         // PID Notch Filter Coefficient N2            
    "i0538 = 0",         // PID Notch Filter Coefficient D1            
    "i0539 = 0",         // PID Notch Filter Coefficient D2            
    "i0540 = 0",         // Trajectory Filter Constant                 
    "i0541 = 0",         // Desired Position Limit Band                

    // Servo/Commutation Modifiers 
    "i0555 = $0",        // 
    "i0556 = 0",         // 
    "i0557 = 0",         // 
    "i0558 = 0",         // 
    "i0559 = 0",         // 
    "i0560 = 0",         // 
    "i0561 = 0",         // 
    "i0562 = 0",         // 
    "i0563 = 4194304",   // 
    "i0564 = 0",         // 
    "i0565 = 16",        // 
    "i0566 = 6527",      // 
    "i0567 = 4194304",   // 
    "i0568 = 0",         // 
    "i0569 = 32767",     // Max DAC Output, 16 bits DAC, ~10V          

    // Backlash 
    "i0585 = 0",         // 
    "i0586 = 0",         // 
    "i0587 = 64",        // 

    // Servo IC Setup - Encoder Setup
    "i7110 = 7",         // Encoder Dir Sense, X4 quadrature CW        
    "i7111 = 0",         // 
    "i7112 = 10",        // Home signal, Flagn Low 
    "i7113 = 0",         // Sec Signal of Dual HMFL                    
    "i7114 = 0",         // 
    "i7115 = 0",         // 
    "i7116 = 3",         // 
    "i7117 = 0",         // 
    "i7118 = 0",         // 
    NULL
};

char * conveyor1_open_loop[]     = {"#5o0"     ,NULL}; // open loop motor 5
char * conveyor1_disable_motor[] = {"i0500 = 0",NULL}; // disable motor 5
char * conveyor1_kill_motor[]    = {"#5k"      ,NULL}; // disable motor 5
char * conveyor1_loop_closure[]  = {"#5$5"     ,NULL}; // close loop 5
char * conveyor1_homing[]        = {"#5hm"     ,NULL}; // homing motor 5

long conveyor1_dac_safe[]             ={0};      // DAC safe check number
array double conveyor1_counts_rev[]   ={2000};   // encoder resolution
array double conveyor1_JM_matrix[1][1]={502.4};  // gear ratio
array double conveyor1_enc_offset[]   ={0};      // encoder offset

#endif                  // Conveyor1_h 

