/*****************************************************
* File name: robot.h
* Note: header file for multiple robot manipulatio 
* Created by Harry H. Cheng and Xudong Hu, 6/28/1999
* Modified by Stephen S. Nestinger to work with the
*   TURBO PMAC 2 PCI under Windows XP
******************************************************/
#ifndef _Robot_H
#define _Robot_H

#pragma package <chrobot>

#include <array.h>
#include <stdbool.h>

#include <robot1.h>
#include <robot2.h>
#include <conveyor.h>

#define MAX_LINE 1024

// workcell run_type options
#define RUN_REALTIME   1 
#define RUN_SIMULATION 0

class CRobot {
    private:
      int  m_robot;      // robot number 
      int  m_numjts;     // number of joints
      bool m_simul;      // true for similation, false for realtime
      int  m_pmacdev;    // store the PMAC device number robot is attached to
      bool m_status;     // status of the Robot, setup = 1, not-setup = 0
      char m_pmacobuf[MAX_LINE];
      char m_pmacibuf[MAX_LINE];

      //-------------------------------------------------------------------
      // The following was added for inverse dynamics computation 
      // by Yu-Cheng Chou 6/13/2007 
      array double w[6][3],
                   w_dot[6][3],
                   v_dot[6][3],
                   a_com[6][3];
      array double F[6][3],
                   N[6][3],
                   f[7][3],
                   n[7][3];
      //-------------------------------------------------------------------

      int SetupRobot1();
      int SetupRobot2();
      int SetupConveyor();
      int DacsRobot1();
      int DacsRobot2();
      int DacsConveyor();
      int CalibrateRobot1();
      int CalibrateRobot2();
      int CalibrateConveyor();
      int DisableRobot1();
      int DisableRobot2();
      int DisableConveyor();
      int InverseKinematicsRobot1(array double trans[4][4], 
                                  array double jointold[:], 
                                  joint[:], int conf);
      int InverseKinematicsRobot2(array double trans[4][4], 
                                  array double jointold[:], 
                                  joint[:], int conf);
      int DriveRobot1(array double disp[]);
      int DriveRobot2(array double disp[]);
      int DriveConveyor(array double disp[]);
      int Robot1GripperClose();
      int Robot2GripperClose();
      int Robot1GripperOpen();
      int Robot2GripperOpen();
      int Robot1MoveHome();
      int Robot2MoveHome();
      int Robot1MoveReady();
      int Robot2MoveReady();
      int Robot1MoveWait();
      int Robot2MoveWait();
      int ConveyorMoveWait();
      int Robot1MoveZero();
      int Robot2MoveZero();
      int Robot1JointSpeed(int speed[]);
      int Robot2JointSpeed(int speed[]);
      int ConveyorJointSpeed(int speed[]);
      int OpenPMAC();
      int ClosePMAC();

      //-------------------------------------------------------------------
      // The following was added for inverse dynamics computation 
      // by Yu-Cheng Chou 6/13/2007 
      void Robot1RotMatrix(array double R[3][3], 
                                        DH[4][4]);

      void Robot1AngVel(array double w_c[3], 
                                     R_inv[3][3], 
                                     w_p[3], 
                                     z[3], 
                              double q_dot);

      void Robot1AngAccel(array double w_dot_c[3], 
                                       R_inv[3][3], 
                                       w_dot_p[3], 
                                       z[3], 
                                       w_p[3], 
                                double q_ddot, 
                                       q_dot); 

      void Robot1Accel(array double v_dot_c[3], 
                                    w_dot_c[3], 
                                    p_star[3], 
                                    w_c[3], 
                                    R_inv[3][3], 
                                    v_dot_p[3]);

      void Robot1AccelCOM(array double a_com[3], 
                                       w_dot_c[3], 
                                       s[3], 
                                       w_c[3], 
                                       v_dot_c[3]);

      void Robot1ForceCOM(array double F[3], 
                                       a_com[3], 
                                double m);

      void Robot1MomentCOM(array double N[3], 
                                        I[3][3], 
                                        w_dot_c[3], 
                                        w_c[3]);

      void Robot1Force(array double f_c[3], 
                                    R[3][3], 
                                    f_n[3], 
                                    F[3]);

      void Robot1Moment(array double n_c[3], 
                                     R[3][3], 
                                     n_n[3], 
                                     R_inv[3][3], 
                                     p_star[3], 
                                     f_n[3], 
                                     s[3], 
                                     F[3], 
                                     N[3]);

      void InverseDynamicsRobot1(array double torque[:], 
                                              q[:], 
                                              q_dot[:], 
                                              q_ddot[:]);

      void AngVelAllRobot1(array double avelall[:][:], 
                                        q[:],
                                        qdot[:],
                                        qddot[:]);

      void AngVelRobot1(array double avel[:], 
                                     q[:],
                                     qdot[:],
                                     qddot[:],
                                 int i);

      void AngAccelAllRobot1(array double aaccelall[:][:], 
                                          q[:],
                                          qdot[:],
                                          qddot[:]);

      void AngAccelRobot1(array double aaccel[:], 
                                       q[:],
                                       qdot[:],
                                       qddot[:],
                                   int i);

      void LinAccelAllRobot1(array double laccelall[:][:], 
                                          q[:],
                                          qdot[:],
                                          qddot[:]);

      void LinAccelRobot1(array double laccel[:], 
                                       q[:],
                                       qdot[:],
                                       qddot[:],
                                   int i);

      void LinAccelComAllRobot1(array double laccelcomall[:][:], 
                                             q[:],
                                             qdot[:],
                                             qddot[:]);

      void LinAccelComRobot1(array double laccelcom[:], 
                                          q[:],
                                          qdot[:],
                                          qddot[:],
                                      int i);

      void ForceComAllRobot1(array double fcomall[:][:], 
                                          q[:],
                                          qdot[:],
                                          qddot[:]);

      void ForceComRobot1(array double fcom[:], 
                                       q[:],
                                       qdot[:],
                                       qddot[:],
                                   int i);

      void MomentComAllRobot1(array double mcomall[:][:], 
                                           q[:],
                                           qdot[:],
                                           qddot[:]);

      void MomentComRobot1(array double mcom[:], 
                                        q[:],
                                        qdot[:],
                                        qddot[:],
                                    int i);

      void ForceAllRobot1(array double forceall[:][:], 
                                       q[:],
                                       qdot[:],
                                       qddot[:]);

      void ForceRobot1(array double force[:], 
                                    q[:],
                                    qdot[:],
                                    qddot[:],
                                int i);

      void MomentAllRobot1(array double momentall[:][:], 
                                        q[:],
                                        qdot[:],
                                        qddot[:]);

      void MomentRobot1(array double moment[:], 
                                     q[:],
                                     qdot[:],
                                     qddot[:],
                                 int i);
      //-------------------------------------------------------------------

    public:

/* these functions are public for testing in command line mode only. 
   Do not use them in application programs. */
      int DacsCheck();
      int Disable();     // disable motor and open the control loop
      int Setup();

      CRobot(int robotnum, char run_type);
      ~CRobot();

      int Calibrate();
      int Drive(array double disp[]);
      int GripperClose();
      int GripperOpen();
      int InverseKinematics(array double trans[4][4], 
                            array double joint[:], 
                            jointold[:], int conf);
      int MoveLine();
      int MoveHome();
      int MoveReady();
      int MoveZero();
      int MoveWait();
      int JointSpeed(int speed[]);
      int CalibratePots();

      //-------------------------------------------------------------------
      // The following was added for inverse dynamics computation 
      // by Yu-Cheng Chou 6/13/2007 
      int InverseDynamics(array double torque[:], 
                                       q[:], 
                                       q_dot[:], 
                                       q_ddot[:]);

      int AngVelAll(array double avelall[:][:], 
                                 q[:],
                                 qdot[:],
                                 qddot[:]);

      int AngVel(array double avel[:], 
                              q[:],
                              qdot[:],
                              qddot[:],
                          int i);

      int AngAccelAll(array double aaccelall[:][:], 
                                   q[:],
                                   qdot[:],
                                   qddot[:]);

      int AngAccel(array double aaccel[:], 
                                q[:],
                                qdot[:],
                                qddot[:],
                            int i);

      int LinAccelAll(array double laccelall[:][:], 
                                   q[:],
                                   qdot[:],
                                   qddot[:]);

      int LinAccel(array double laccel[:], 
                                q[:],
                                qdot[:],
                                qddot[:],
                            int i);

      int LinAccelComAll(array double laccelcomall[:][:], 
                                      q[:],
                                      qdot[:],
                                      qddot[:]);

      int LinAccelCom(array double laccelcom[:], 
                                   q[:],
                                   qdot[:],
                                   qddot[:],
                               int i);

      int ForceComAll(array double fcomall[:][:], 
                                   q[:],
                                   qdot[:],
                                   qddot[:]);

      int ForceCom(array double fcom[:], 
                                q[:],
                                qdot[:],
                                qddot[:],
                            int i);

      int MomentComAll(array double mcomall[:][:], 
                                    q[:],
                                    qdot[:],
                                    qddot[:]);

      int MomentCom(array double mcom[:], 
                                 q[:],
                                 qdot[:],
                                 qddot[:],
                             int i);

      int ForceAll(array double forceall[:][:], 
                                q[:],
                                qdot[:],
                                qddot[:]);

      int Force(array double force[:], 
                             q[:],
                             qdot[:],
                             qddot[:],
                         int i);

      int MomentAll(array double momentall[:][:], 
                                 q[:],
                                 qdot[:],
                                 qddot[:]);

      int Moment(array double moment[:], 
                              q[:],
                              qdot[:],
                              qddot[:],
                          int i);
      //-------------------------------------------------------------------
};

#pragma importf <CRobot.chf>

#endif   /*  _Robot_H */

