/*************************************************
*  Program Name:  robot2.h
*
*  Functionality:  Provide setup information
*                  for the Unimate IBM 7575 
*                  robot.
*  
*  Author:   Jat S. Pannu
*  Modified: Jonathan Larson   on Jul  9, 1996
*  Modified: Xudong Hu         on Mar 25, 1999
*  Modified: Stephen Nestinger on Aug 21, 2006
*************************************************/

#ifndef Robot2_h
#define Robot2_h

#define ROBOT2 2
#define ROBOT2_PMAC 1 // PMAC device number robot is attached to
#define ROBOT2_NUM_JOINTS 4 

#define NOFLIP 0b000
#define FLIP   0b100

long robot2_dac_safe[] = 
{
   5000,  /* DAC output full range is -32767 to +32767 (16 bits for +/-10V) */
   5000,
   5000,
   5000
};

/*  NOTE 1:  Actual Encoder resolution  */
/*  for each encoder is 500 cts/rev.    */
/*  Quadrature multiplying in software  */
/*  boots resolution to 2000 cts/rev    */

double robot2_counts_rev[] =             
{                                  
   2000,                            
   2000,                         
   2000,
   2000
};

double robot2_enc_offset[] = 
{
   0,       /* robot2 zero position is the same of the ready position */
   0,
   0,
   0
}; 

/* IBM 7575 DATA 

#define   G1        -60.0    thetat 1 gear ratio 
#define   G2        51.0     theta  2 gear ratio 
#define   G3        42.114   Z-axis   gear ratio 
#define   G4        50.0     Roll   4 gear ratio 

               ---                                      ---
               |                                          |
               |     1/G1     0     0          0          |
               |                                          |
               |      0     1/G2    0          0          |
Theta[j] =     |                                          |Theta[m]
               |      0       0   1/G3         0          |
               |                                          |
               |    -1/G1  -1/G2    0        1/G4         |
               |                                          |
               ---                                      ___
*/

array double robot2_JM_matrix[][4] = 
{
    { -0.016667, 0.0,      0.0,      0.0    }, 
    { 0.0,       0.019607, 0.0,      0.0    },
    { 0.0,       0.0,      0.023745, 0.0    },
    { 0.016667, -0.019607, 0.0,      0.0200 }
};

/* define robotic parament:by Xudong Hu
   robot2ZeroPosition: Transformation matrix for zero position
   robot2_B - TF matrix from base to coordinate
   robot2_H - TF matrix from link6 to the tool coordinate frame
   robot2_alpha - DH parament
   robot2_d - DH parament
   robot2_a - DH parament  */

array double robot2ZeroPosition[4][4] = {{1, 0, 0, -213.2},
                                         {0, 1, 0, -62.30},
                                         {0, 0, 1,  0    },
                                         {0, 0, 0,  1    }};

array double robot2_B[4][4] = {{1, 0, 0, 0},
                               {0, 1, 0, 0},
                               {0, 0, 1, 0},
                               {0, 0, 0, 1}};

/*
array double robot2_H[4][4] = {{1, 0, 0, 0},
                               {0, 1, 0, 0},
                               {0, 0, 1, 0},
                               {0, 0, 0, 1}};
*/

// With gripper
array double robot2_H[4][4] = {{1, 0, 0,  60},
                               {0, 1, 0,   0},
                               {0, 0, 1, -17},
                               {0, 0, 0,   1}};

array double robot2_alpha[6] = {0,   0,   0, 0, 0, 0},
                 robot2_d[6] = {0,   0,   0, 0, 0, 0},
                 robot2_a[6] = {325, 225, 0, 0, 0, 0};
 
/* PMAC  Data */

char* robot2_init[][69] = 
{{ /* Motor 1 */
    /* Definition */
    "i0100 = 1",         /* Motor Enable                               */
    "i0101 = 0",         /* Commutation Disable                        */
    "i0102 = $78002",    /* DAC Output Address                         */
    "i0103 = $3501",     /* Pos FB Data Address                        */
    "i0104 = $3501",     /* Vel FB Data Address                        */
    "i0105 = $35C0",     /* Master Position Address                    */
    "i0106 = 0",         /* Master Follow Enable                       */
    "i0107 = 96",        /* Master Scale Factor                        */
    "i0108 = 96",        /* Position Scale Factory                     */
    "i0109 = 96",        /* Velocity Scale Factor                      */
    "i0110 = $0",        /* Power-on Servo Position Address            */

    /* Safety */
    "i0111 = 0",         /* Disable  Motor Fatal following Error limit */
    "i0112 = 0",         /* Disable  Motor Warn following Error limit  */
    "i0113 = 1",         /* Software Pos Limit +, Unit: Encoder Counts */
    "i0114 = -80000",    /* Software Pos Limit -, Unit: Encoder Counts */
    "i0115 = 0.25",      /* Pos Limit Decel Rate, Unit: Counts/msec^2  */
    "i0116 = 0.2",       /* Max Velocity, Unit: Counts/msec^2          */
    "i0117 = 0.02",      /* Max Acceleration, Unit: Counts/msec^2      */
    //"i0118 = 0.0",     /* Reserved                                   */
    "i0119 = 0.20",      /* Max Jog Acceleration, Unit: Counts/msec^2  */

    /* Movement */
    "i0120 = 1",         /* Motor Jog/Home Accel Time, Unit: msec      */
    "i0121 = 0",         /* Motor Jog/Home S-Curve Time,   Unit: msec  */
    "i0122 = 7",         /* Motor Jog Speed, Unit: Counts/msec         */
    "i0123 = 4",         /* Motor Home Speed & Dir, Unit: Counts/msec  */
    "i0124 = $120001",   /* Motor Flag Mode Control                    */
    "i0125 = $78000",    /* Motor Flag Address                         */
    "i0126 = 0",         /* Motor Home Offset                          */
    "i0127 = 0",         /* Motor Position Rollover Range              */
    "i0128 = 200",       /* Motor In-Position Band                     */
    "i0129 = 0",         /* Motor Output/1st Phase Offset              */

    /* Basic Servo */
    "i0130 = 500000",    /* PID Proportional Gain, Unit: DAVbits/Count */
    "i0131 = 2000",      /* PID Derivative Gain, DACbits/(Counts/cycle)*/
    "i0132 = 2000",      /* PID Vel FF Gain, DACbits/(Counts/cycle)    */
    "i0133 = 500",       /* PID Inte Gain, DACbits/(Counts*cycles)     */
    "i0134 = 1",         /* PID Inte Mode                              */
    "i0135 = 0",         /* PID Accel FF Gain, DACbits/(Counts/cycle^2)*/
    "i0136 = 0",         /* PID Notch Filter Coefficient N1            */
    "i0137 = 0",         /* PID Notch Filter Coefficient N2            */
    "i0138 = 0",         /* PID Notch Filter Coefficient D1            */
    "i0139 = 0",         /* PID Notch Filter Coefficient D2            */
    "i0140 = 0",         /* Trajectory Filter Constant                 */
    "i0141 = 0",         /* Desired Position Limit Band                */

    /* Servo/Commutation Modifiers */
    "i0155 = $0",        /* */
    "i0156 = 0",         /* */
    "i0157 = 0",         /* */
    "i0158 = 0",         /* */
    "i0159 = 0",         /* */
    "i0160 = 0",         /* */
    "i0161 = 0",         /* */
    "i0162 = 0",         /* */
    "i0163 = 4194304",   /* */
    "i0164 = 0",         /* */
    "i0165 = 16",        /* */
    "i0166 = 6527",      /* */
    "i0167 = 4194304",   /* */
    "i0168 = 0",         /* */
    "i0169 = 9800",      /* Max DAC Output, 16 bits DAC, ~10V          */

    /* Backlash */
    "i0185 = 0",         /* */
    "i0186 = 0",         /* */
    "i0187 = 64",        /* */

    /* Servo IC Setup - Encoder Setup*/
    "i7010 = 3",         /* Encoder Dir Sense, X4 quadrature CW        */
    "i7011 = 0",         /* */
    "i7012 = 11",        /* Dual home signal, Rising edge of CHCn & Flagn */
    "i7013 = 0",         /* Sec Signal of Dual HMFL                    */
    "i7014 = 0",         /* */
    "i7015 = 0",         /* */
    "i7016 = 3",         /* */
    "i7017 = 0",         /* */
    "i7018 = 0",         /* */
    NULL
 },
 { /* Motor 2 */
    /* Definition */
    "i0200 = 1",         /* Motor Enable                               */
    "i0201 = 0",         /* Commutation Disable                        */
    "i0202 = $7800A",    /* DAC Output Address                         */
    "i0203 = $3502",     /* Pos FB Data Address                        */
    "i0204 = $3502",     /* Vel FB Data Address                        */
    "i0205 = $35C0",     /* Master Position Address                    */
    "i0206 = 0",         /* Master Follow Enable                       */
    "i0207 = 96",        /* Master Scale Factor                        */
    "i0208 = 96",        /* Position Scale Factory                     */
    "i0209 = 96",        /* Velocity Scale Factor                      */
    "i0210 = $0",        /* Power-on Servo Position Address            */

    /* Safety */
    "i0211 = 0",         /* Disable  Motor Fatal following Error limit */
    "i0212 = 0",         /* Disable  Motor Warn following Error limit  */
    "i0213 = 80000",     /* Software Pos Limit +, Unit: Encoder Counts */
    "i0214 = 1",         /* Software Pos Limit -, Unit: Encoder Counts */
    "i0215 = 0.25",      /* Pos Limit Decel Rate, Unit: Counts/msec^2  */
    "i0216 = 0.2",       /* Max Velocity, Unit: Counts/msec^2          */
    "i0217 = 0.02",      /* Max Acceleration, Unit: Counts/msec^2      */
    //"i0218 = 0.0",     /* Reserved                                   */
    "i0219 = 0.20",      /* Max Jog Acceleration, Unit: Counts/msec^2  */

    /* Movement */
    "i0220 = 1",         /* Motor Jog/Home Accel Time, Unit: msec      */
    "i0221 = 0",         /* Motor Jog/Home S-Curve Time,   Unit: msec  */
    "i0222 = 7",         /* Motor Jog Speed, Unit: Counts/msec         */
    "i0223 = -4",        /* Motor Home Speed & Dir, Unit: Counts/msec  */
    "i0224 = $120001",   /* Motor Flag Mode Control                    */
    "i0225 = $78008",    /* Motor Flag Address                         */
    "i0226 = 0",         /* Motor Home Offset                          */
    "i0227 = 0",         /* Motor Position Rollover Range              */
    "i0228 = 200",       /* Motor In-Position Band                     */
    "i0229 = 0",         /* Motor Output/1st Phase Offset              */

    /* Basic Servo */
    "i0230 = 500000",    /* PID Proportional Gain, Unit: DAVbits/Count */
    "i0231 = 2000",      /* PID Derivative Gain, DACbits/(Counts/cycle)*/
    "i0232 = 2000",      /* PID Vel FF Gain, DACbits/(Counts/cycle)    */
    "i0233 = 500",       /* PID Inte Gain, DACbits/(Counts*cycles)     */
    "i0234 = 1",         /* PID Inte Mode                              */
    "i0235 = 0",         /* PID Accel FF Gain, DACbits/(Counts/cycle^2)*/
    "i0236 = 0",         /* PID Notch Filter Coefficient N1            */
    "i0237 = 0",         /* PID Notch Filter Coefficient N2            */
    "i0238 = 0",         /* PID Notch Filter Coefficient D1            */
    "i0239 = 0",         /* PID Notch Filter Coefficient D2            */
    "i0240 = 0",         /* Trajectory Filter Constant                 */
    "i0241 = 0",         /* Desired Position Limit Band                */

    /* Servo/Commutation Modifiers */
    "i0255 = $0",        /* */
    "i0256 = 0",         /* */
    "i0257 = 0",         /* */
    "i0258 = 0",         /* */
    "i0259 = 0",         /* */
    "i0260 = 0",         /* */
    "i0261 = 0",         /* */
    "i0262 = 0",         /* */
    "i0263 = 4194304",   /* */
    "i0264 = 0",         /* */
    "i0265 = 16",        /* */
    "i0266 = 6527",      /* */
    "i0267 = 4194304",   /* */
    "i0268 = 0",         /* */
    "i0269 = 9800",      /* Max DAC Output, 16 bits DAC, ~10V          */

    /* Backlash */
    "i0285 = 0",         /* */
    "i0286 = 0",         /* */
    "i0287 = 64",        /* */

    /* Servo IC Setup - Encoder Setup*/
    "i7020 = 3",         /* Encoder Dir Sense, X4 quadrature CW        */
    "i7021 = 0",         /* */
    "i7022 = 11",        /* Dual home signal, Rising edge of CHCn & Flagn */
    "i7023 = 0",         /* Sec Signal of Dual HMFL                    */
    "i7024 = 0",         /* */
    "i7025 = 0",         /* */
    "i7026 = 3",         /* */
    "i7027 = 0",         /* */
    "i7028 = 0",         /* */
    NULL
 },
 { /* Motor 3 */
    /* Definition */
    "i0300 = 1",         /* Motor Enable                               */
    "i0301 = 0",         /* Commutation Disable                        */
    "i0302 = $78012",    /* DAC Output Address                         */
    "i0303 = $3503",     /* Pos FB Data Address                        */
    "i0304 = $3503",     /* Vel FB Data Address                        */
    "i0305 = $35C0",     /* Master Position Address                    */
    "i0306 = 0",         /* Master Follow Enable                       */
    "i0307 = 96",        /* Master Scale Factor                        */
    "i0308 = 96",        /* Position Scale Factory                     */
    "i0309 = 96",        /* Velocity Scale Factor                      */
    "i0310 = $0",        /* Power-on Servo Position Address            */

    /* Safety */
    "i0311 = 0",         /* Disable  Motor Fatal following Error limit */
    "i0312 = 0",         /* Disable  Motor Warn following Error limit  */
    "i0313 = 1",         /* Software Pos Limit +, Unit: Encoder Counts */
    "i0314 = -35000",    /* Software Pos Limit -, Unit: Encoder Counts */
    "i0315 = 0.25",      /* Pos Limit Decel Rate, Unit: Counts/msec^2  */
    "i0316 = 0.2",       /* Max Velocity, Unit: Counts/msec^2          */
    "i0317 = 0.02",      /* Max Acceleration, Unit: Counts/msec^2      */
    //"i0318 = 0.0",     /* Reserved                                   */
    "i0319 = 0.20",      /* Max Jog Acceleration, Unit: Counts/msec^2  */

    /* Movement */
    "i0320 = 1",         /* Motor Jog/Home Accel Time, Unit: msec      */
    "i0321 = 0",         /* Motor Jog/Home S-Curve Time,   Unit: msec  */
    "i0322 = 7",         /* Motor Jog Speed, Unit: Counts/msec         */
    "i0323 = 4",        /* Motor Home Speed & Dir, Unit: Counts/msec  */
    "i0324 = $120001",   /* Motor Flag Mode Control                    */
    "i0325 = $78010",    /* Motor Flag Address                         */
    "i0326 = 0",         /* Motor Home Offset                          */
    "i0327 = 0",         /* Motor Position Rollover Range              */
    "i0328 = 200",       /* Motor In-Position Band                     */
    "i0329 = 0",         /* Motor Output/1st Phase Offset              */

    /* Basic Servo */
    "i0330 = 500000",    /* PID Proportional Gain, Unit: DAVbits/Count */
    "i0331 = 2000",      /* PID Derivative Gain, DACbits/(Counts/cycle)*/
    "i0332 = 2000",      /* PID Vel FF Gain, DACbits/(Counts/cycle)    */
    "i0333 = 500",       /* PID Inte Gain, DACbits/(Counts*cycles)     */
    "i0334 = 1",         /* PID Inte Mode                              */
    "i0335 = 0",         /* PID Accel FF Gain, DACbits/(Counts/cycle^2)*/
    "i0336 = 0",         /* PID Notch Filter Coefficient N1            */
    "i0337 = 0",         /* PID Notch Filter Coefficient N2            */
    "i0338 = 0",         /* PID Notch Filter Coefficient D1            */
    "i0339 = 0",         /* PID Notch Filter Coefficient D2            */
    "i0340 = 0",         /* Trajectory Filter Constant                 */
    "i0341 = 0",         /* Desired Position Limit Band                */

    /* Servo/Commutation Modifiers */
    "i0355 = $0",        /* */
    "i0356 = 0",         /* */
    "i0357 = 0",         /* */
    "i0358 = 0",         /* */
    "i0359 = 0",         /* */
    "i0360 = 0",         /* */
    "i0361 = 0",         /* */
    "i0362 = 0",         /* */
    "i0363 = 4194304",   /* */
    "i0364 = 0",         /* */
    "i0365 = 16",        /* */
    "i0366 = 6527",      /* */
    "i0367 = 4194304",   /* */
    "i0368 = 0",         /* */
    //"i0369 = 9800",      /* Max DAC Output, 16 bits DAC, ~10V          */
    "i0369 = 2000",      /* Max DAC Output, 16 bits DAC, ~10V          */

    /* Backlash */
    "i0385 = 0",         /* */
    "i0386 = 0",         /* */
    "i0387 = 64",        /* */

    /* Servo IC Setup - Encoder Setup*/
    "i7030 = 3",         /* Encoder Dir Sense, X4 quadrature CW        */
    "i7031 = 0",         /* */
    "i7032 = 11",        /* Dual home signal, Rising edge of CHCn & Flagn */
    "i7033 = 0",         /* Sec Signal of Dual HMFL                    */
    "i7034 = 0",         /* */
    "i7035 = 0",         /* */
    "i7036 = 3",         /* */
    "i7037 = 0",         /* */
    "i7038 = 0",         /* */
    NULL
 },
 { /* Motor 4 */
    /* Definition */
    "i0400 = 1",         /* Motor Enable                               */
    "i0401 = 0",         /* Commutation Disable                        */
    "i0402 = $7801A",    /* DAC Output Address                         */
    "i0403 = $3504",     /* Pos FB Data Address                        */
    "i0404 = $3504",     /* Vel FB Data Address                        */
    "i0405 = $35C0",     /* Master Position Address                    */
    "i0406 = 0",         /* Master Follow Enable                       */
    "i0407 = 96",        /* Master Scale Factor                        */
    "i0408 = 96",        /* Position Scale Factory                     */
    "i0409 = 96",        /* Velocity Scale Factor                      */
    "i0410 = $0",        /* Power-on Servo Position Address            */

    /* Safety */
    "i0411 = 0",         /* Disable  Motor Fatal following Error limit */
    "i0412 = 0",         /* Disable  Motor Warn following Error limit  */
    "i0413 = 100000",    /* Software Pos Limit +, Unit: Encoder Counts */
    "i0414 = -100000",   /* Software Pos Limit -, Unit: Encoder Counts */
    "i0415 = 0.25",      /* Pos Limit Decel Rate, Unit: Counts/msec^2  */
    "i0416 = 0.2",       /* Max Velocity, Unit: Counts/msec^2          */
    "i0417 = 0.02",      /* Max Acceleration, Unit: Counts/msec^2      */
    //"i0418 = 0.0",     /* Reserved                                   */
    "i0419 = 0.20",      /* Max Jog Acceleration, Unit: Counts/msec^2  */

    /* Movement */
    "i0420 = 1",         /* Motor Jog/Home Accel Time, Unit: msec      */
    "i0421 = 0",         /* Motor Jog/Home S-Curve Time,   Unit: msec  */
    "i0422 = 10",        /* Motor Jog Speed, Unit: Counts/msec         */
    "i0423 = 3",         /* Motor Home Speed & Dir, Unit: Counts/msec  */
    "i0424 = $120001",   /* Motor Flag Mode Control                    */
    "i0425 = $78018",    /* Motor Flag Address                         */
    "i0426 = 0",         /* Motor Home Offset                          */
    "i0427 = 0",         /* Motor Position Rollover Range              */
    "i0428 = 200",       /* Motor In-Position Band                     */
    "i0429 = 0",         /* Motor Output/1st Phase Offset              */

    /* Basic Servo */
    "i0430 = 500000",    /* PID Proportional Gain, Unit: DAVbits/Count */
    "i0431 = 2000",      /* PID Derivative Gain, DACbits/(Counts/cycle)*/
    "i0432 = 2000",      /* PID Vel FF Gain, DACbits/(Counts/cycle)    */
    "i0433 = 500",       /* PID Inte Gain, DACbits/(Counts*cycles)     */
    "i0434 = 1",         /* PID Inte Mode                              */
    "i0435 = 0",         /* PID Accel FF Gain, DACbits/(Counts/cycle^2)*/
    "i0436 = 0",         /* PID Notch Filter Coefficient N1            */
    "i0437 = 0",         /* PID Notch Filter Coefficient N2            */
    "i0438 = 0",         /* PID Notch Filter Coefficient D1            */
    "i0439 = 0",         /* PID Notch Filter Coefficient D2            */
    "i0440 = 0",         /* Trajectory Filter Constant                 */
    "i0441 = 0",         /* Desired Position Limit Band                */

    /* Servo/Commutation Modifiers */
    "i0455 = $0",        /* */
    "i0456 = 0",         /* */
    "i0457 = 0",         /* */
    "i0458 = 0",         /* */
    "i0459 = 0",         /* */
    "i0460 = 0",         /* */
    "i0461 = 0",         /* */
    "i0462 = 0",         /* */
    "i0463 = 4194304",   /* */
    "i0464 = 0",         /* */
    "i0465 = 16",        /* */
    "i0466 = 6527",      /* */
    "i0467 = 4194304",   /* */
    "i0468 = 0",         /* */
    "i0469 = 9800",      /* Max DAC Output, 16 bits DAC, ~10V          */

    /* Backlash */
    "i0485 = 0",         /* */
    "i0486 = 0",         /* */
    "i0487 = 64",        /* */

    /* Servo IC Setup - Encoder Setup*/
    "i7040 = 3",         /* Encoder Dir Sense, X4 quadrature CW        */
    "i7041 = 0",         /* */
    "i7042 = 11",        /* Dual home signal, Rising edge of CHCn & Flagn */
    "i7043 = 0",         /* Sec Signal of Dual HMFL                    */
    "i7044 = 0",         /* */
    "i7045 = 0",         /* */
    "i7046 = 3",         /* */
    "i7047 = 0",         /* */
    "i7048 = 0",         /* */
    NULL
 }
}; 
 
char* robot2_kill_motors[] = 
{
   "#1K",                     /* Kill Motor 1 output */
   "#2K",                     /* Kill Motor 2 output */
   "#3K",                     /* Kill Motor 3 output */
   "#4K",                     /* Kill Motor 3 output */
   NULL
};

char* robot2_open_loop[] = 
{
    "#1o0",                   /* Opening Loop for Jt 1     */
    "#2o0",                   /* Opening Loop for Jt 2     */
    "#3o0",                   /* Opening Loop for Jt 3     */
    "#4o0",                   /* Opening Loop for Jt 4     */
    NULL     
};

char* robot2_disable_motor[] =
{
    "i0100 = 0",              /* Disable Motor 1           */
    "i0200 = 0",              /* Disable Motor 2           */
    "i0300 = 0",              /* Disable Motor 3           */
    "i0400 = 0",              /* Disable Motor 4           */
    "M0 = 1",                 /* Disable Amp 1             */
    "M1 = 1",                 /* Disable Amp 2             */
    "M2 = 1",                 /* Disable Amp 3             */
    "M3 = 1",                 /* Disable Amp 4             */
    "M4 = 1",                 /* Disable Startup Enable    */
    "M5 = 1",                 /* Release Z-axis Brake      */
/* According to the manu of operation, when disable the robot,
   Z-axis brake must be engaged. But when the brake was engaged,
   the DACs test of robot was not correct. So set the brake in
   release state. This means that when the machine is power on,
   Z-axis brake is released utill the power is shutdown.
               Setup by Xudong Hu                          */
    NULL
};

char* robot2_home[] =
{
   "0",                 /* Joint1 home Position    */
   "0",                 /* Joint2 home Position    */
   "0",                 /* Joint3 home Position    */
   "0",                 /* Joint4 home Position    */
    NULL
}; 

char* robot2_homing[] =
{
   "#1hm",                 /* Homing Motor 1            */
   "#2hm",                 /* Homing Motor 2            */
   "#3hm",                 /* Homing Motor 3            */
   "#4hm",                 /* Homing Motor 4            */
    NULL
}; 

 
char* robot2_ready[] = 
{
   "120.0",               /*  Joint 1 ready position  */
   "143.0",               /*  Joint 2 ready position  */
   "-75.0",               /*  Joint 3 ready position  */
     "0.0",               /*  Joint 4 ready position  */
   NULL
};
 
char* robot2_zero[] = 
{
   "0",                 /*  Joint 1 zero position  */
   "0",                 /*  Joint 2 zero position  */
   "0",                 /*  Joint 3 zero position  */
   "0",                 /*  Joint 4 zero position  */
   NULL
};
 

 
char* robot2_loop_closure[] = 
{
    "#1j/",             /* restore joint 1 closed-loop control */
    "#2j/",             /* restore joint 2 closed-loop control */
    "#3j/",             /* restore joint 3 closed-loop control */
    "#4j/",             /* restore joint 4 closed-loop control */
    "M32=255",          /* Direction control for M0..7         */
    "M33=1",            /* Buffer direction control for M0..7  */
    "M0=0",             /* Enable Amp 1                        */
    "M1=0",             /* Enable Amp 2                        */
    "M2=0",             /* Enable Amp 3                        */
    "M3=0",             /* Enable Amp 4                        */
    "M4=0",             /* Startup Enable                      */
    "M5=0",             /* Z-Axis Brake release                */
    "M6=1",             /* Start with gripper closed           */
    NULL
};

char * robot2_grip_close[] = 
{
    "M6=1",                    /* close gripper          */
    NULL
};
 
char * robot2_grip_open[] = 
{
    "M6=0",                    /* open gripper           */
    NULL
};

#endif                         /* Robot_h                */
